/// <reference types="react" />
import { Vector3 } from '@kitware/vtk.js/types';
export interface PickResult {
    representationId?: string;
    worldPosition: Vector3;
    displayPosition: Vector3;
    compositeID: number;
    ray: [Vector3, Vector3];
}
export interface FrustumPickResult {
    frustum: number[][];
    representationIds: string[];
}
interface Props {
    /**
     * Whether to enable picking and callbacks.
     *
     * Defaults to true.
     */
    enabled?: boolean;
    /**
     * Callback when an actor is hovered.
     *
     * @param selection Selection info
     * @param event the originating pointer event
     */
    onHover?: (selection: PickResult, event: PointerEvent) => void;
    /**
     * Callback when an actor is clicked with a mouse.
     *
     * @param selection Selection info
     * @param event the originating mouse event
     */
    onClick?: (selection: PickResult, event: MouseEvent) => void;
    /**
     * Callback when the pointer is pressed down on an actor.
     *
     * @param selection Selection info
     * @param event the originating pointer event
     */
    onPointerDown?: (selection: PickResult, event: PointerEvent) => void;
    /**
     * Callback when the pointer is pressed up on an actor.
     *
     * @param selection Selection info
     * @param event the originating pointer event
     */
    onPointerUp?: (selection: PickResult, event: PointerEvent) => void;
    /**
     * Defines the tolerance of the click and hover selection.
     */
    pointerSize?: number;
    /**
     * Sets the debounce wait for onHover calls.
     *
     * This is only useful if you desire to reduce the frequency
     * at which onHover is called.
     */
    onHoverDebounceWait?: number;
}
declare const _default: import("react").ForwardRefExoticComponent<Props & import("react").RefAttributes<unknown>>;
export default _default;
