import { PropsWithChildren } from 'react';
import { VtkConstructor } from '../types';
export interface ReaderProps extends PropsWithChildren {
    /**
     * Can either be a string containing the name of the vtkClass or a vtk object constructor.
     *
     * If a string, then that vtk class must be registered (i.e. by import).
     */
    vtkClass: string | VtkConstructor;
    /**
     * An optional port number for connections.
     */
    port?: number;
    /**
     * Download data from a URL.
     *
     * Must be CORS-accessible.
     *
     * This option is for convenience. If you want more fine-grained
     * control over fetching (i.e. aborting, options, etc.) then it
     * is advisable to fetch the data yourself and pass it into the
     * reader via `arrayBuffer`, `base64ArrayBuffer`, or `text`.
     */
    url?: string;
    /**
     * An object of options passed to the reader's setUrl() function.
     *
     * See the reader's docs for more details.
     */
    urlOptions?: object;
    /**
     * ArrayBuffer containing data to parse.
     */
    arrayBuffer?: ArrayBuffer;
    /**
     * ArrayBuffer containing data to parse, in a base64 string.
     */
    base64ArrayBuffer?: string;
    /**
     * Textual representation of the data.
     */
    text?: string;
}
/**
 * Reads data and produces vtkObjects.
 */
export default function Reader(props: ReaderProps): void;
