import { ICameraInitialValues } from '@kitware/vtk.js/Rendering/Core/Camera';
import { Vector3, Vector4 } from '@kitware/vtk.js/types';
import { PropsWithChildren } from 'react';
export interface Props extends PropsWithChildren {
    /**
     * The color of the view background using 3 floating numbers
     * between 0-1 of Red, Green, Blue component.
     */
    background?: Vector3 | Vector4;
    /**
     * Whether this renderer is interactive.
     */
    interactive?: boolean;
    /**
     * Camera properties, such as position, focal point, etc.
     */
    camera?: ICameraInitialValues;
    /**
     * Whether to automatically call resetCamera() (default: true)
     *
     * When set to true, resetCamera() will be invoked whenever
     * a render is requested due to a pipeline update, e.g. the data
     * changed or a representation property was modified.
     *
     * When set to false, the user must explicitly provide camera
     * properties. Note that the initial resetCamera() call will
     * still occur upon component mount.
     */
    autoResetCamera?: boolean;
}
export declare const DefaultProps: {
    background: Vector3;
    interactive: boolean;
    autoResetCamera: boolean;
};
declare const _default: import("react").ForwardRefExoticComponent<Props & import("react").RefAttributes<unknown>>;
export default _default;
