import { jsx } from 'react/jsx-runtime';
import { useRef, useCallback, useEffect } from 'react';
import { ResizeWatcher, ResizeWatcherContext } from '../utils/ResizeWatcher.js';
import { MultiViewRootContext } from './contexts.js';
import OpenGLRenderWindow from './OpenGLRenderWindow.js';
import RenderWindow from './RenderWindow.js';

const RW_STYLE = {
    pointerEvents: 'none',
};
function MultiViewRoot(props) {
    const openGLRenderWindowRef = useRef(null);
    const renderWindowRef = useRef(null);
    const resizeWatcherRef = useRef(new ResizeWatcher());
    const onResize = useCallback((target) => {
        const oglrw = openGLRenderWindowRef.current;
        const rw = renderWindowRef.current;
        if (!oglrw || !rw)
            return;
        const devicePixelRatio = window.devicePixelRatio || 1;
        const { width, height } = target.getBoundingClientRect();
        const w = Math.floor(width * devicePixelRatio);
        const h = Math.floor(height * devicePixelRatio);
        oglrw.get().setSize(Math.max(w, 10), Math.max(h, 10));
        rw.requestRender();
    }, []);
    useEffect(() => {
        const oglrw = openGLRenderWindowRef.current;
        const container = oglrw === null || oglrw === void 0 ? void 0 : oglrw.getContainer();
        if (oglrw && container) {
            const resize = resizeWatcherRef.current;
            resize.watch(container, onResize);
            return () => {
                resize.unwatch(container, onResize);
            };
        }
    }, [onResize]);
    return (jsx(ResizeWatcherContext.Provider, Object.assign({ value: resizeWatcherRef.current }, { children: jsx(MultiViewRootContext.Provider, Object.assign({ value: true }, { children: jsx(OpenGLRenderWindow, Object.assign({}, props, { renderWindowStyle: RW_STYLE, ref: openGLRenderWindowRef }, { children: jsx(RenderWindow, Object.assign({ ref: renderWindowRef }, { children: props.children })) })) })) })));
}

export { MultiViewRoot as default };
