import vtkColorTransferFunction from '@kitware/vtk.js/Rendering/Core/ColorTransferFunction';
import vtkColorMaps from '@kitware/vtk.js/Rendering/Core/ColorTransferFunction/ColorMaps';
import { compareVector2 } from '../../utils/comparators.js';
import deletionRegistry from '../../utils/DeletionRegistry.js';
import useComparableEffect from '../../utils/useComparableEffect.js';
import useGetterRef from '../../utils/useGetterRef.js';
import useUnmount from '../../utils/useUnmount.js';

function useColorTransferFunction(presetName, range, trackModified) {
    const [lutRef, getLUT] = useGetterRef(() => {
        const func = vtkColorTransferFunction.newInstance();
        deletionRegistry.register(func, () => func.delete());
        return func;
    });
    useComparableEffect(() => {
        if (!presetName || !range)
            return;
        const lut = getLUT();
        const preset = vtkColorMaps.getPresetByName(presetName);
        lut.applyColorMap(preset);
        lut.setMappingRange(range[0], range[1]);
        lut.updateRange();
        trackModified(true);
    }, [presetName, range], ([curPreset, curRange], [oldPreset, oldRange]) => curPreset === oldPreset && compareVector2(curRange, oldRange));
    useUnmount(() => {
        if (lutRef.current) {
            deletionRegistry.markForDeletion(lutRef.current);
            lutRef.current = null;
        }
    });
    return getLUT;
}

export { useColorTransferFunction as default };
