import vtkCoordinate from '@kitware/vtk.js/Rendering/Core/Coordinate';
import { compareShallowObject } from '../../utils/comparators.js';
import deletionRegistry from '../../utils/DeletionRegistry.js';
import useComparableEffect from '../../utils/useComparableEffect.js';
import useGetterRef from '../../utils/useGetterRef.js';
import useUnmount from '../../utils/useUnmount.js';

function useCoordinate(props, trackModified) {
    const [ref, getCoordinate] = useGetterRef(() => {
        const coord = vtkCoordinate.newInstance(props);
        deletionRegistry.register(coord, () => coord.delete());
        return coord;
    });
    useComparableEffect(() => {
        if (!props)
            return;
        getCoordinate().set(props);
        trackModified(true);
    }, [props], ([cur], [prev]) => compareShallowObject(cur, prev));
    useUnmount(() => {
        if (ref.current) {
            deletionRegistry.markForDeletion(ref.current);
            ref.current = null;
        }
    });
    return getCoordinate;
}

export { useCoordinate as default };
