type DeletionCallback = (obj: unknown) => void;
/**
 * Tracks the usage of a particular object, triggering a deletion callback when refs hit zero and the object is marked for deletion.
 *
 * register() is the entrypoint for tracking an object.
 * markForDeletion() is the counterpart to register(), indicating that the object should be deleted in the future.
 * incRefCount() and decRefCount() should be used to track when code uses/stops using the object.
 * unregister() is used only if there's not reason to continue tracking the object.
 */
export declare class DeletionRegistry {
    private refCount;
    private callbacks;
    private toDelete;
    constructor();
    get liveCount(): number;
    register(obj: unknown, deleteCallback: DeletionCallback): void;
    unregister(obj: unknown): void;
    markForDeletion(obj: unknown): void;
    incRefCount(obj: unknown): void;
    decRefCount(obj: unknown): void;
    private tryToDispose;
}
declare const deletionRegistry: DeletionRegistry;
export default deletionRegistry;
