import { useRef, useEffect } from 'react';

function getElementTarget(target) {
    if (typeof target === 'function') {
        return target();
    }
    if (target && 'current' in target) {
        return target.current;
    }
    return target;
}
/**
 * Event Listener.
 *
 * The typing currently only supports HTMLElement targets.
 */
function useEventListener(target, eventName, callback, options) {
    // avoid add/remove listener whenever callback changes
    const cachedCallback = useRef(callback);
    useEffect(() => {
        cachedCallback.current = callback;
    }, [callback]);
    useEffect(() => {
        const el = getElementTarget(target);
        if (el) {
            el.addEventListener(eventName, cachedCallback.current, options);
            return () => {
                el.removeEventListener(eventName, cachedCallback.current, options);
            };
        }
    }, [eventName, options, target]);
}

export { useEventListener };
